# Microservices Authentication

## Description

A set of simple utility classes for d4k microservices authentication.

## Installation

```bash
pip install d4k_ms_auth
```

## Building package

Use pip to install build and twine. Use the following commands to build

```python -m build``` 

and upload to pypi.org using the command

```twine upload dist/*``` 
